fn modifier_safe_vars<'gcx>(
gcx: Gcx<'gcx>,
invocation: &'gcx Modifier<'gcx>,
) -> Vec<VariableId>Expand description
Caller variables proven trusted by the statements a modifier runs before _: a parameter that
is bound to the variable, never reassigned in the prefix, and safe when _ is reached.